GlassPy documentation — GlassPy latest documentation

# GlassPy documentation

GlassPy is a Python module for researchers working with glass materials and glass-forming liquids. Currently, GlassPy focuses on glass data and predictive models. GlassPy provides a convenient way to load data from the SciGlass database into a Pandas DataFrame. GlassPy is also the home to GlassNet and ViscNet. GlassNet is a predictive model for many glass properties. ViscNet is a predictive model for viscosity. GlassPy is still under heavy development; changes to the API are not only likely, but expected as development continues.

## First steps

Installation guide

  Install GlassPy on your computer.

Examples

  Check out some examples of what GlassPy can do.

## API Documentation

- glasspy
  - glasspy package

## Indices and tables

- Index

- Module Index

- Search Page